@@ -8,7 +8,7 @@
 __author__ = "Ben Foster"
 __copyright__ = "Copyright 2020, Retronix"
 __license__ = "MIT"
-__version__ = "1.1.1"
+__version__ = "1.1.2"
 __maintainer__ = "Ben Foster"
 __email__ = "ben@retronixmc.org"
 __status__ = "Development"
@@ -50,5 +50,18 @@ class Client:
         
         Raises:
             RateLimitError: This happens when the API returns an error stating that the token used is currently in cooldown.
+            ClientNotStartedError: Thrown when the client class hasn't been started.
         """
-        return []
\ No newline at end of file
+        return []
+    def getState(self):
+        """
+        Checks to see if the client is online or not.
+        """
+    def login(self, token):
+        """
+        Start the client and log into the API.
+
+        Parameters:
+            token (str): (Required) Token to use when signing onto the API.
+        """
+        self.__token = token
\ No newline at end of file
